#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"

#include "sgipkg.h"

extern GdkColor color_warning_message;
extern char *warning_message[];
extern GtkWidget *wss;
extern GtkWidget *wrc;

/*---------------------------------------------------------------------
 * Event: window main
 *---------------------------------------------------------------------*/

void
on_WindowMain_destroy (GtkObject * object, gpointer user_data)
{
  gtk_exit (0);
}


gboolean
on_WindowMain_destroy_event (GtkWidget * widget,
			     GdkEvent * event, gpointer user_data)
{
  return FALSE;
}

/*---------------------------------------------------------------------
 * Event: exit
 *---------------------------------------------------------------------*/

void
on_exit_activate (GtkMenuItem * menuitem, gpointer user_data)
{
  gtk_exit (0);
}


/*---------------------------------------------------------------------
 * Event: Information
 *---------------------------------------------------------------------*/

void
on_info_activate (GtkMenuItem * menuitem, gpointer user_data)
{
#ifdef LOCKED
  if (!isLocked ())
    {
#endif
      if (isSelected ())
	{
	  do_ipkg_info (get_selected_package ());
	}
      else
	{
	  clear_message ();
	  write_message (_(warning_message[0]), &color_warning_message);
	}
#ifdef LOCKED
    }
#endif
}

void
on_depends_activate (GtkMenuItem * menuitem, gpointer user_data)
{
#ifdef LOCKED
  if (!isLocked ())
    {
#endif
      if (isSelected ())
	{
	  do_ipkg_depends (get_selected_package ());
	}
      else
	{
	  clear_message ();
	  write_message (_(warning_message[0]), &color_warning_message);
	}
#ifdef LOCKED
    }
#endif
}


void
on_search_activate (GtkMenuItem * menuitem, gpointer user_data)
{
#ifdef LOCKED
  if (!isLocked ())
    {
#endif
      if (isSelected ())
	{
	  do_ipkg_search (get_selected_package ());
	}
      else
	{
	  clear_message ();
	  write_message (_(warning_message[0]), &color_warning_message);
	}
#ifdef LOCKED
    }
#endif
}


void
on_status_activate (GtkMenuItem * menuitem, gpointer user_data)
{
#ifdef LOCKED
  if (!isLocked ())
    {
#endif
      if (isSelected ())
	{
	  do_ipkg_status (get_selected_package ());
	}
      else
	{
	  clear_message ();
	  write_message (_(warning_message[0]), &color_warning_message);
	}
#ifdef LOCKED
    }
#endif
}

/*---------------------------------------------------------------------
 * Event: Manipulation
 *---------------------------------------------------------------------*/

void
on_install_activate (GtkMenuItem * menuitem, gpointer user_data)
{
#ifdef LOCKED
  if (!isLocked ())
    {
#endif
      if (isInstalled ())
	{
	  clear_message ();
	  write_message (_(warning_message[2]), &color_warning_message);
	}
      else if (isSelected ())
	{
	  do_ipkg_install (get_selected_package ());
	}
      else
	{
	  clear_message ();
	  write_message (_(warning_message[0]), &color_warning_message);
	}
      // no need refresh.
#ifdef LOCKED
    }
#endif
}


void
on_remove_activate (GtkMenuItem * menuitem, gpointer user_data)
{
  GtkWidget *WindowRemove;

#ifdef LOCKED
  if (!isLocked ())
    {
#endif
      if (isInstalled ())
	{
	  WindowRemove = create_WindowRemove ();

	  write_package_name (WindowRemove);
	  gtk_widget_show (WindowRemove);
	}
      else if (isSelected ())
	{
	  clear_message ();
	  write_message (_(warning_message[1]), &color_warning_message);
	}
      else
	{
	  clear_message ();
	  write_message (_(warning_message[0]), &color_warning_message);
	}
#ifdef LOCKED
    }
#endif
}

void
on_update_list_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
#ifdef LOCKED
  if (!isLocked ())
    {
#endif
      do_ipkg_update_list ();
#ifdef LOCKED
    }
#endif
}


void
on_update_activate (GtkMenuItem * menuitem, gpointer user_data)
{
#ifdef LOCKED
  if (!isLocked ())
    {
#endif
      if (isInstalled ())
	{
	  do_ipkg_update (get_selected_package ());
	}
      else if (isSelected ())
	{
	  clear_message ();
	  write_message (_(warning_message[0]), &color_warning_message);
	}
      else
	{
	  clear_message ();
	  write_message (_(warning_message[1]), &color_warning_message);
	}
      // no need refresh
#ifdef LOCKED
    }
#endif
}


void
on_upgrade_activate (GtkMenuItem * menuitem, gpointer user_data)
{
#ifdef LOCKED
  if (!isLocked ())
    {
#endif
      do_ipkg_upgrade ();
      // no need refresh
#ifdef LOCKED
    }
#endif
}

/*---------------------------------------------------------------------
 * Event: about dialog
 *---------------------------------------------------------------------*/

void
on_about_activate (GtkMenuItem * menuitem, gpointer user_data)
{
  GtkWidget *WindowAbout;
  WindowAbout = create_WindowAbout ();
  gtk_widget_show (WindowAbout);
}

/*---------------------------------------------------------------------
 * Event: cList 
 *---------------------------------------------------------------------*/

void
on_clist_click_column (GtkCList * clist, gint column, gpointer user_data)
{
  ;
}


void
on_clist_select_row (GtkCList * clist,
		     gint row,
		     gint column, GdkEvent * event, gpointer user_data)
{
  gchar *pk;

  gtk_clist_get_text (clist, row, 0, &pk);
  set_selected_package (pk);
}

/*---------------------------------------------------------------------
 * Event: cList Label
 *---------------------------------------------------------------------*/

gboolean
on_label_c1_button_press_event (GtkWidget * widget,
				GdkEventButton * event, gpointer user_data)
{
  return FALSE;
}


gboolean
on_Lst_c2_button_press_event (GtkWidget * widget,
			      GdkEventButton * event, gpointer user_data)
{
  return FALSE;
}


gboolean
on_Lst_c3_button_press_event (GtkWidget * widget,
			      GdkEventButton * event, gpointer user_data)
{
  return FALSE;
}


gboolean
on_Lst_c4_button_press_event (GtkWidget * widget,
			      GdkEventButton * event, gpointer user_data)
{
  return FALSE;
}

/*---------------------------------------------------------------------
 * Event: radiobutton
 *---------------------------------------------------------------------*/

void
on_radiobutton_all_pressed (GtkButton * button, gpointer user_data)
{
  action_radiobutton (VIEW_ALL);
}


void
on_radiobutton_installed_pressed (GtkButton * button, gpointer user_data)
{
  action_radiobutton (VIEW_INSTALLED);
}


void
on_radiobutton_uninstalled_pressed (GtkButton * button, gpointer user_data)
{
  action_radiobutton (VIEW_UNINSTALLED);
}

/*---------------------------------------------------------------------
 * Event: about_ok
 *---------------------------------------------------------------------*/

gboolean
on_WindowAbout_button_press_event (GtkWidget * widget,
				   GdkEventButton * event, gpointer user_data)
{
  return FALSE;
}

/*---------------------------------------------------------------------
 * Event: exit_ok
 *---------------------------------------------------------------------*/

void
on_Exit_clicked (GtkButton * button, gpointer user_data)
{
  gtk_widget_destroy (gtk_widget_get_toplevel (GTK_WIDGET (button)));
  gtk_exit (0);
}

/*---------------------------------------------------------------------
 * Event: remove dialog
 *---------------------------------------------------------------------*/

void
on_removeOK_clicked (GtkButton * button, gpointer user_data)
{
  do_ipkg_remove (get_selected_package ());
  refresh ();
  gtk_widget_destroy (gtk_widget_get_toplevel (GTK_WIDGET (button)));
}


void
on_removeCancel_clicked (GtkButton * button, gpointer user_data)
{
  gtk_widget_destroy (gtk_widget_get_toplevel (GTK_WIDGET (button)));
}


/*---------------------------------------------------------------------
 * Event: ipkg.conf configure
 *---------------------------------------------------------------------*/

void
on_source_select_activate (GtkMenuItem * menuitem, gpointer user_data)
{
  GtkWidget *WindowConf;

  if (check_conf_file ())
    {
      WindowConf = create_WindowConf ();
      gtk_widget_show (WindowConf);
      
      wss = WindowConf;
      init_window_conf ();
    }
  else
    {
      clear_message ();
      write_message (_(warning_message[3]), &color_warning_message);
    }
}


/*---------------------------------------------------------------------
 * Event: configure
 *---------------------------------------------------------------------*/

void
on_winconf_note_switch_page (GtkNotebook * notebook,
			     GtkNotebookPage * page,
			     gint page_num, gpointer user_data)
{
  clear_winconf_text_entry ((int) page_num);
}


void
on_winconf_clist_source_select_row (GtkCList * clist,
				    gint row,
				    gint column,
				    GdkEvent * event, gpointer user_data)
{
  set_winconf_entry (SOURCE, row);
}


void
on_winconf_source_add_clicked (GtkButton * button, gpointer user_data)
{
  do_winconf_add (SOURCE);
}


void
on_winconf_source_edit_clicked (GtkButton * button, gpointer user_data)
{
  do_winconf_edit (SOURCE);
}


void
on_winconf_source_delete_clicked (GtkButton * button, gpointer user_data)
{
  do_winconf_delete (SOURCE);
}


void
on_winconf_clist_dest_select_row (GtkCList * clist,
				  gint row,
				  gint column,
				  GdkEvent * event, gpointer user_data)
{
  set_winconf_entry (DEST, row);
}


void
on_winconf_dest_add_clicked (GtkButton * button, gpointer user_data)
{
  do_winconf_add (DEST);
}


void
on_winconf_dest_edit_clicked (GtkButton * button, gpointer user_data)
{
  do_winconf_edit (DEST);
}


void
on_winconf_dest_delete_clicked (GtkButton * button, gpointer user_data)
{
  do_winconf_delete (DEST);
}


void
on_winconf_clist_proxy_select_row (GtkCList * clist,
				   gint row,
				   gint column,
				   GdkEvent * event, gpointer user_data)
{
  set_winconf_entry (PROXY, row);
}


void
on_winconf_proxy_add_clicked (GtkButton * button, gpointer user_data)
{
  do_winconf_add (PROXY);
}


void
on_winconf_proxy_edit_clicked (GtkButton * button, gpointer user_data)
{
  do_winconf_edit (PROXY);
}


void
on_winconf_proxy_delete_clicked (GtkButton * button, gpointer user_data)
{
  do_winconf_delete (PROXY);
}


void
on_winconf_close_clicked (GtkButton * button, gpointer user_data)
{
  gtk_widget_destroy (gtk_widget_get_toplevel (GTK_WIDGET (button)));
}

/*---------------------------------------------------------------------
 * Event: 
 *---------------------------------------------------------------------*/
void
on_winconf_remove_check_ok_clicked (GtkButton * button, gpointer user_data)
{
  do_winconf_remove ();
  gtk_widget_destroy (gtk_widget_get_toplevel (GTK_WIDGET (button)));
}


void
on_winconf_remove_check_cancel_clicked (GtkButton * button,
					gpointer user_data)
{
  gtk_widget_destroy (gtk_widget_get_toplevel (GTK_WIDGET (button)));
}

/* EOF */

